@@ -1,7 +1,7 @@
 import re
 import json
 
-with open('tranlist.json', 'r', encoding='utf-8') as f:
+with open('./tranlist.json', 'r', encoding='utf-8') as f:
     tranlist = json.load(f)
 
 def tran(err:str)->str:
