@@ -3,7 +3,7 @@ import zlcython,json,opencc,coderun
 def runcode(codes):
     decodecode=''
     for code in codes:
-        with open('liblist.json', 'r', encoding='utf-8') as f:
+        with open('./liblist.json', 'r', encoding='utf-8') as f:
             libusedict = json.load(f)
         for lib, info in libusedict.items():
             if info[0]:
